@@ -14,6 +14,7 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/render"
+	"github.com/derailed/k9s/internal/view/cmd"
 	"k8s.io/apimachinery/pkg/runtime"
 )
 
@@ -22,21 +23,23 @@ var _ Accessor = (*Alias)(nil)
 // Alias tracks standard and custom command aliases.
 type Alias struct {
 	NonResource
+
 	*config.Aliases
 }
 
 // NewAlias returns a new set of aliases.
 func NewAlias(f Factory) *Alias {
-	a := Alias{Aliases: config.NewAliases()}
+	a := Alias{
+		Aliases: config.NewAliases(),
+	}
 	a.Init(f, client.NewGVR("aliases"))
 
 	return &a
 }
 
 // Check verifies an alias is defined for this command.
-func (a *Alias) Check(cmd string) bool {
-	_, ok := a.Aliases.Get(cmd)
-	return ok
+func (a *Alias) Check(cmd string) (string, bool) {
+	return a.Aliases.Get(cmd)
 }
 
 // List returns a collection of aliases.
@@ -49,19 +52,30 @@ func (a *Alias) List(ctx context.Context, _ string) ([]runtime.Object, error) {
 	oo := make([]runtime.Object, 0, len(m))
 	for gvr, aliases := range m {
 		sort.StringSlice(aliases).Sort()
-		oo = append(oo, render.AliasRes{GVR: gvr, Aliases: aliases})
+		oo = append(oo, render.AliasRes{
+			GVR:     gvr,
+			Aliases: aliases,
+		})
 	}
 
 	return oo, nil
 }
 
 // AsGVR returns a matching gvr if it exists.
-func (a *Alias) AsGVR(cmd string) (client.GVR, bool) {
-	gvr, ok := a.Aliases.Get(cmd)
-	if ok {
-		return client.NewGVR(gvr), true
+func (a *Alias) AsGVR(c string) (client.GVR, string, bool) {
+	exp, ok := a.Aliases.Get(c)
+	if !ok {
+		return client.NoGVR, "", ok
 	}
-	return client.GVR{}, false
+	p := cmd.NewInterpreter(exp)
+	if strings.Contains(p.Cmd(), "/") {
+		return client.NewGVR(p.Cmd()), "", true
+	}
+	if gvr, ok := a.Aliases.Get(p.Cmd()); ok {
+		return client.NewGVR(gvr), exp, true
+	}
+
+	return client.NoGVR, "", false
 }
 
 // Get fetch a resource.
@@ -70,15 +84,15 @@ func (a *Alias) Get(_ context.Context, _ string) (runtime.Object, error) {
 }
 
 // Ensure makes sure alias are loaded.
-func (a *Alias) Ensure() (config.Alias, error) {
+func (a *Alias) Ensure(path string) (config.Alias, error) {
 	if err := MetaAccess.LoadResources(a.Factory); err != nil {
 		return config.Alias{}, err
 	}
-	return a.Alias, a.load()
+	return a.Alias, a.load(path)
 }
 
-func (a *Alias) load() error {
-	if err := a.Load(); err != nil {
+func (a *Alias) load(path string) error {
+	if err := a.Load(path); err != nil {
 		return err
 	}
 
