@@ -29,7 +29,14 @@ func (n *NonResource) Init(f Factory, gvr client.GVR) {
 	n.mx.Unlock()
 }
 
-func (n *NonResource) GetFactory() Factory {
+func (n *NonResource) gvrStr() string {
+	n.mx.RLock()
+	defer n.mx.RUnlock()
+
+	return n.gvr.String()
+}
+
+func (n *NonResource) getFactory() Factory {
 	n.mx.RLock()
 	defer n.mx.RUnlock()
 
@@ -41,7 +48,7 @@ func (n *NonResource) GVR() string {
 	n.mx.RLock()
 	defer n.mx.RUnlock()
 
-	return n.gvr.String()
+	return n.gvrStr()
 }
 
 // Get returns the given resource.
