@@ -15,6 +15,7 @@ import (
 	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
+	"github.com/rs/zerolog/log"
 )
 
 // Table represents a table viewer.
@@ -46,6 +47,13 @@ func (t *Table) Init(ctx context.Context) (err error) {
 		ctx = context.WithValue(ctx, internal.KeyHasMetrics, t.app.Conn().HasMetrics())
 	}
 	ctx = context.WithValue(ctx, internal.KeyStyles, t.app.Styles)
+	if !t.app.Config.K9s.UI.Reactive {
+		if err := t.app.RefreshCustomViews(); err != nil {
+			log.Warn().Err(err).Msg("CustomViews load failed")
+			t.app.Logo().Warn("Views load failed!")
+		}
+	}
+
 	ctx = context.WithValue(ctx, internal.KeyViewConfig, t.app.CustomView)
 	t.Table.Init(ctx)
 	t.SetInputCapture(t.keyboard)
